"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const CompletionsProvider_1 = require("../CompletionsProvider");
const docset_1 = require("../../docset");
const common_1 = require("./common");
const globalAttributeNames = [...docset_1.HtmlData.globalAttributes].sort(common_1.sortByName).map((x) => x.name);
const aTag = docset_1.HtmlData.tags.find((x) => x.name === 'a');
const aTagAttributeNames = aTag.attributes.map((x) => x.name);
(0, vitest_1.describe)('Module: HtmlAttributeCompletionProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new CompletionsProvider_1.CompletionsProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [],
            tags: async () => [],
        });
    });
    (0, vitest_1.it)('should complete unknown tag attributes with global attribute', async () => {
        await (0, vitest_1.expect)(provider).to.complete('<unknown █', globalAttributeNames);
    });
    (0, vitest_1.it)("should complete known tags attribute with global attribute names + the tag's attributes", async () => {
        const expected = [...aTagAttributeNames, ...globalAttributeNames].sort();
        await (0, vitest_1.expect)(provider).to.complete('<a █', expected);
    });
    (0, vitest_1.it)('should complete correctly inside if branches as well!', async () => {
        const expected = [...aTagAttributeNames, ...globalAttributeNames].sort();
        await (0, vitest_1.expect)(provider).to.complete('<a {% if cond %}█', expected);
    });
});
//# sourceMappingURL=HtmlAttributeCompletionProvider.spec.js.map