"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const HoverProvider_1 = require("../HoverProvider");
(0, vitest_1.describe)('Module: TranslationHoverProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new HoverProvider_1.HoverProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [],
            tags: async () => [],
        }, async () => ({
            general: {
                password: 'password',
                username_html: '<b>username</b>',
                comments: {
                    one: '{{ count }} comment',
                    other: '{{ count }} comments',
                },
            },
        }));
    });
    (0, vitest_1.it)('should return the hover description of the translation string', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`{{ '█general.password' | t }}`, 'password');
        await (0, vitest_1.expect)(provider).to.hover(`{{ 'general█.username_html' | t }}`, vitest_1.expect.stringMatching('<b>username</b>'));
        await (0, vitest_1.expect)(provider).to.hover(`{{ 'general█.comments' | translate }}`, vitest_1.expect.stringMatching(/one(.|\n)*comment(.|\n)*other(.|\n)*comments/));
    });
    (0, vitest_1.it)('should return nothing if there are no translations for that string', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`{{ 'general.█password' | not_a_translation_filter }}`, null);
        await (0, vitest_1.expect)(provider).to.hover(`{{ 'general.█nope' | t }}`, null);
    });
});
//# sourceMappingURL=TranslationHoverProvider.spec.js.map